@@ -5,13 +5,12 @@ from urduhack.normalization import normalize
 from ..parser import Parser
 
 
-# class for running the tokenizer
 class NormalizeParser(Parser):
-    """pass"""
+    """This parser normalize Urdu text."""
 
     def _set_up(self, config):
         """pass"""
 
     def parse(self, document):
-        """pass"""
+        """Function to normalize text"""
         return normalize(document)
